package de.bsvrz.buv.plugin.darstellung.actions;

import java.util.List;

import org.eclipse.gef.EditPart;
import org.eclipse.gef.EditPartViewer;
import org.eclipse.jface.action.Action;
import org.eclipse.jface.viewers.ISelectionChangedListener;
import org.eclipse.jface.viewers.SelectionChangedEvent;

import de.bsvrz.buv.plugin.darstellung.model.Darstellung;
import de.bsvrz.buv.plugin.darstellung.model.Ebene;
import de.bsvrz.buv.plugin.darstellung.util.DarstellungIcons;

/**
 * Schaltet die markierte Ebene in den Bearbeitungsmodus.
 * 
 * @author BitCtrl Systems GmbH, Falko Schumann
 * @version $Id: EditEbeneAction.java 26913 2010-10-21 22:12:45Z Schumann $
 */
public class EditEbeneAction extends Action implements
		ISelectionChangedListener {

	private final EditPartViewer viewer;

	/**
	 * Initialisiert die Action.
	 * 
	 * @param viewer
	 *            der Viewer mit dem die Action zusammenarbeiten soll.
	 */
	public EditEbeneAction(final EditPartViewer viewer) {
		setText("Ebene bearbeiten");
		setImageDescriptor(DarstellungIcons.ActionEditEbene
				.getImageDescriptor());

		setToolTipText("Versetzt die ausgewhlte Ebene in den Bearbeitungsmodus und alle anderen in den normalen Modus.");

		this.viewer = viewer;
		viewer.addSelectionChangedListener(this);
	}

	@Override
	public void run() {
		final Ebene current = getSelection();
		final Darstellung darstellung = current.getDarstellung();

		for (final Ebene ebene : darstellung.getEbenen()) {
			if (current.equals(ebene)) {
				ebene.setEditable(true);
			} else {
				ebene.setEditable(false);
			}
		}
	}

	private Ebene getSelection() {
		final List<?> editParts = viewer.getSelectedEditParts();
		if (!editParts.isEmpty()
				&& ((EditPart) editParts.get(0)).getModel() instanceof Ebene) {
			return (Ebene) ((EditPart) editParts.get(0)).getModel();
		}

		return null;
	}

	@Override
	public void selectionChanged(final SelectionChangedEvent event) {
		setEnabled(getSelection() != null);
	}

}
