package de.bsvrz.buv.plugin.darstellung.commands;

import org.eclipse.core.runtime.Assert;
import org.eclipse.gef.commands.Command;

import de.bsvrz.buv.plugin.darstellung.model.AutoEbene;
import de.bsvrz.buv.plugin.dobj.model.DoTyp;

/**
 * Fgt einer Autoebene einen Darstellungsobjekttyp hinzu.
 * 
 * @author BitCtrl Systems GmbH, Falko Schumann
 * @version $Id$
 */
public class AddDoTypToAutoEbeneCommand extends Command {

	private final AutoEbene ebene;
	private DoTyp doTyp;
	private boolean useExistsDoTyp;

	public AddDoTypToAutoEbeneCommand(final DoTyp doTyp, final AutoEbene ebene) {
		Assert.isNotNull(doTyp, "doTyp");
		Assert.isNotNull(ebene, "ebene");

		this.doTyp = doTyp;
		this.ebene = ebene;

		setLabel("Darstellungsobjekttyp zur Autoebene hinzufgen");
	}

	@Override
	public boolean canExecute() {
		return !CommandUtil.contains(ebene.getDoTypen(), doTyp);
	}

	@Override
	public void execute() {
		Assert.isTrue(canExecute(), "command is not executable");

		doTyp = mergeDoTypAndCheckIfMustBeHandled(doTyp);

		redo();
	}

	private DoTyp mergeDoTypAndCheckIfMustBeHandled(final DoTyp dot) {
		final DoTyp existsDot = CommandUtil.getDoTyp(ebene.getDarstellung()
				.getDoTypen(), dot);
		if (existsDot != null) {
			useExistsDoTyp = true;
			return existsDot;
		}

		useExistsDoTyp = false;
		return dot;
	}

	@Override
	public void redo() {
		ebene.getDoTypen().add(doTyp);

		if (!useExistsDoTyp) {
			ebene.getDarstellung().getDoTypen().add(doTyp);
		}
	}

	@Override
	public void undo() {
		if (!useExistsDoTyp) {
			ebene.getDarstellung().getDoTypen().remove(doTyp);
		}

		ebene.getDoTypen().remove(doTyp);
	}

}
