package de.bsvrz.buv.plugin.darstellung.commands;

import java.util.ArrayList;
import java.util.Collection;

import de.bsvrz.buv.plugin.darstellung.model.AutoEbene;
import de.bsvrz.buv.plugin.darstellung.model.Darstellung;
import de.bsvrz.buv.plugin.darstellung.model.Ebene;
import de.bsvrz.buv.plugin.dobj.model.ConfiguratedDoTyp;
import de.bsvrz.buv.plugin.dobj.model.DoKomponente;
import de.bsvrz.buv.plugin.dobj.model.DoKompositum;
import de.bsvrz.buv.plugin.dobj.model.DoModel;
import de.bsvrz.buv.plugin.dobj.model.DoTyp;
import de.bsvrz.buv.plugin.doeditor.model.EditorDoTypReferenz;

public final class CommandUtil {

	/**
	 * Prft, ob ein gegebener Darstellungsobjekttyp in einer Menge von
	 * Darstellungsobjekttypen enthalten ist.
	 */
	static boolean contains(final Collection<DoTyp> doTypen, final DoTyp doTyp) {
		return getDoTyp(doTypen, doTyp) != null;
	}

	/**
	 * Prft, ob ein gegebener Darstellungsobjekttyp in einer Menge von
	 * Darstellungsobjekttypen enthalten ist.
	 * 
	 * @return ist der Darstellungsobjekttyp in der Menge enthalten, wird der
	 *         entsprechende Darstellungsobjekttyp <em>aus der Menge</em>
	 *         zurckgegeben. Sonst <code>null</code>.
	 */
	static DoTyp getDoTyp(final Collection<DoTyp> doTypen, final DoTyp doTyp) {
		if (doTyp instanceof ConfiguratedDoTyp) {
			final ConfiguratedDoTyp modelDot = (ConfiguratedDoTyp) doTyp;
			for (final DoTyp dot : doTypen) {
				if (dot instanceof ConfiguratedDoTyp) {
					final ConfiguratedDoTyp darstellungDot = ((ConfiguratedDoTyp) dot);
					if (modelDot.getId().equals(darstellungDot.getId())) {
						return darstellungDot;
					}
				}
			}
		} else if (doTyp instanceof EditorDoTypReferenz) {
			final EditorDoTypReferenz modelDot = (EditorDoTypReferenz) doTyp;
			for (final DoTyp dot : doTypen) {
				if (dot instanceof EditorDoTypReferenz) {
					final EditorDoTypReferenz darstellungDot = ((EditorDoTypReferenz) dot);
					if (modelDot.getSystemObjekt().equals(
							darstellungDot.getSystemObjekt())) {
						return darstellungDot;
					}
				}
			}
		}

		// fallback
		return null;
	}

	/**
	 * Prft ob es ein Darstellungsobjekt in einer Darstellung gibt, welches den
	 * angegebenen Darstellungsobjekttyp verwendet.
	 */
	static boolean isUsedDoTypInDarstellung(final DoTyp doTyp,
			final Darstellung darstellung, final AutoEbene excludeEbene) {
		return isUsedDoTypInDarstellung(doTyp, darstellung,
				new ArrayList<DoModel>(), excludeEbene);
	}

	/**
	 * Prft ob es ein Darstellungsobjekt in einer Darstellung gibt, welches den
	 * angegebenen Darstellungsobjekttyp verwendet. Die Darstellungsobjekte in
	 * der Ausschlussliste werden dabei nicht mitgezhlt.
	 */
	private static boolean isUsedDoTypInDarstellung(final DoTyp doTyp,
			final Darstellung darstellung, final Collection<DoModel> excludes,
			final AutoEbene excludeEbene) {
		for (final Ebene ebene : darstellung.getEbenen()) {
			if (ebene instanceof AutoEbene && ebene != excludeEbene) {
				final AutoEbene autoEbene = (AutoEbene) ebene;
				for (final DoTyp dot : autoEbene.getDoTypen()) {
					if (dot == doTyp) {
						return true;
					}
				}
			}

			for (final DoModel model : ebene.getDoObjekte()) {
				if (excludes.contains(model)) {
					continue;
				} else if (model.getDoTyp() == doTyp) {
					return true;
				} else if (model instanceof DoKompositum<?>) {
					@SuppressWarnings("unchecked")
					final DoKompositum<DoModel> kompositum = (DoKompositum<DoModel>) model;
					if (isUsedDoTypInKompositum(doTyp, kompositum, excludes)) {
						return true;
					}
				}
			}
		}

		// fallback
		return false;
	}

	private static boolean isUsedDoTypInKompositum(final DoTyp doTyp,
			final DoKompositum<DoModel> kompositum,
			final Collection<DoModel> excludes) {
		for (final DoKomponente komponente : kompositum.getKomponenten()) {
			if (komponente instanceof DoModel) {
				final DoModel model = (DoModel) komponente;
				if (excludes.contains(model)) {
					continue;
				} else if (model.getDoTyp() == doTyp) {
					return true;
				} else if (model instanceof DoKompositum<?>) {
					@SuppressWarnings("unchecked")
					final DoKompositum<DoModel> k = (DoKompositum<DoModel>) model;
					if (isUsedDoTypInKompositum(doTyp, k, excludes)) {
						return true;
					}
				}
			}
		}

		// fallback
		return false;
	}

	private CommandUtil() {
		// utility class
	}

}
