package de.bsvrz.buv.plugin.darstellung.dialogs;

import org.eclipse.jface.dialogs.IInputValidator;
import org.eclipse.jface.dialogs.InputDialog;
import org.eclipse.ui.PlatformUI;

import de.bsvrz.buv.plugin.darstellung.model.Ansicht;
import de.bsvrz.buv.plugin.darstellung.model.Ausschnitt;

public class AusschnittAnlegenDialog extends InputDialog {

	private static final String ERROR_TEXT_LEER = "Der Name fr den Ausschnitt darf nicht leer sein";
	private static final String WARNUNG_TEXT_OVERWRITE = "Der Ausschnit existiert bereits und wird berschrieben!";
	private Ansicht ansicht;

	public AusschnittAnlegenDialog(final Ansicht ansicht) {
		super(PlatformUI.getWorkbench().getActiveWorkbenchWindow().getShell(),
				"Ausschnitt speichern",
				"Geben Sie einen Namen fr den zu speichernden Ausschnitt an!",
				"", new IInputValidator() {

					@Override
					public String isValid(final String newText) {
						String result = null;
						final String newName = newText.trim();

						if (newName.isEmpty()) {
							result = ERROR_TEXT_LEER;
						} else if (ansicht != null) {
							for (final Ausschnitt ausschnitt : ansicht
									.getAusschnitte()) {
								if (ausschnitt.getName().equals(newName)) {
									result = WARNUNG_TEXT_OVERWRITE;
								}
							}
						}

						return result;
					}
				});

		this.ansicht = ansicht;
	}

	@Override
	public void setErrorMessage(final String errorMessage) {
		super.setErrorMessage(errorMessage);
		if (WARNUNG_TEXT_OVERWRITE.equals(errorMessage)) {
			getOkButton().setEnabled(true);
		}
	}
}
