package de.bsvrz.buv.plugin.darstellung.dialogs;

import org.eclipse.gef.dnd.SimpleObjectTransfer;
import org.eclipse.jface.viewers.StructuredViewer;

/**
 * Drag'n'Drop Transfer fr beliebige Objekte. Da die Objekte nicht
 * (de-)serialisiert werden, funktioniert der Drag'n'Drop nur innerhalb einer
 * Instanz einer Eclipse-Applikation.
 * 
 * @author BitCtrl Systems GmbH, Falko Schumann
 * @version $Id$
 */
public class ViewerTransfer extends SimpleObjectTransfer {

	private static final ViewerTransfer INSTANCE = new ViewerTransfer();
	private static final String TYPE_NAME = "Local Transfer"//$NON-NLS-1$
			+ System.currentTimeMillis() + ":" + INSTANCE.hashCode();//$NON-NLS-1$
	private static final int TYPEID = registerType(TYPE_NAME);

	private static StructuredViewer viewer;

	/**
	 * Returns the singleton instance.
	 * 
	 * @return The singleton instance
	 */
	public static ViewerTransfer getInstance() {
		return INSTANCE;
	}

	private ViewerTransfer() {
		// hide constructor
	}

	/**
	 * @see org.eclipse.swt.dnd.Transfer#getTypeIds()
	 */
	@Override
	protected int[] getTypeIds() {
		return new int[] { TYPEID };
	}

	/**
	 * @see org.eclipse.swt.dnd.Transfer#getTypeNames()
	 */
	@Override
	protected String[] getTypeNames() {
		return new String[] { TYPE_NAME };
	}

	/**
	 * Returns the viewer where the drag started.
	 * 
	 * @return The viewer where the drag started
	 */
	public StructuredViewer getViewer() {
		return viewer;
	}

	/**
	 * Sets the viewer where the drag started.
	 * 
	 * @param viewer
	 *            The viewer
	 */
	public void setViewer(final StructuredViewer viewer) {
		ViewerTransfer.viewer = viewer;
	}

}
