package de.bsvrz.buv.plugin.darstellung.editors;

import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.List;
import java.util.Map;
import java.util.SortedMap;
import java.util.TreeMap;

import net.sf.paperclips.BigPrint;
import net.sf.paperclips.GridColumn;
import net.sf.paperclips.GridPrint;
import net.sf.paperclips.ImagePrint;
import net.sf.paperclips.PagePrint;
import net.sf.paperclips.TextPrint;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Platform;
import org.eclipse.draw2d.SWTGraphics;
import org.eclipse.emf.common.notify.Adapter;
import org.eclipse.emf.common.notify.Notification;
import org.eclipse.emf.common.notify.impl.AdapterImpl;
import org.eclipse.gef.EditPart;
import org.eclipse.gef.EditPartFactory;
import org.eclipse.gef.GraphicalEditPart;
import org.eclipse.gef.ui.actions.ActionRegistry;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.ErrorDialog;
import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.FontData;
import org.eclipse.swt.graphics.GC;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.graphics.Rectangle;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Display;
import org.eclipse.ui.IEditorInput;
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.views.contentoutline.IContentOutlinePage;

import com.bitctrl.lib.eclipse.emf.util.EmfUtil;

import de.bsvrz.buv.plugin.darstellung.actions.DarstellungActionConstants;
import de.bsvrz.buv.plugin.darstellung.actions.SelectAusschnittAction;
import de.bsvrz.buv.plugin.darstellung.actions.ToggleEbenenAction;
import de.bsvrz.buv.plugin.darstellung.actions.ToggleOverviewAction;
import de.bsvrz.buv.plugin.darstellung.actions.ToggleSynchronizeSelectionAction;
import de.bsvrz.buv.plugin.darstellung.editparts.DarstellungEditPartFactory;
import de.bsvrz.buv.plugin.darstellung.editparts.tree.DarstellungTreeEditPartFactory;
import de.bsvrz.buv.plugin.darstellung.model.Ansicht;
import de.bsvrz.buv.plugin.darstellung.model.Darstellung;
import de.bsvrz.buv.plugin.darstellung.model.DarstellungPackage;
import de.bsvrz.buv.plugin.darstellung.model.Ebene;
import de.bsvrz.buv.plugin.darstellung.util.AnsichtenEinstellungen;
import de.bsvrz.buv.plugin.dobj.actions.EllipseSelectionAction;
import de.bsvrz.buv.plugin.dobj.actions.FixViewportAction;
import de.bsvrz.buv.plugin.dobj.actions.PolygonSelectionAction;
import de.bsvrz.buv.plugin.dobj.actions.RectangleSelectionAction;
import de.bsvrz.buv.plugin.dobj.actions.StreckeSelectionAction;
import de.bsvrz.buv.plugin.dobj.actions.ToggleAntiKollisionsAlgorithmusAction;
import de.bsvrz.buv.plugin.dobj.actions.ToggleBaustelleGueltigAction;
import de.bsvrz.buv.plugin.dobj.actions.ToggleSelectionFeedbackAction;
import de.bsvrz.buv.plugin.dobj.actions.ToggleTouchedSelectionAction;
import de.bsvrz.buv.plugin.dobj.actions.ToggleVerbindungslinieAction;
import de.bsvrz.buv.plugin.dobj.editors.DobjGraphicalEditor;
import de.bsvrz.buv.plugin.dobj.internal.DObjPlugin;
import de.bsvrz.buv.plugin.dobj.model.DoModel;
import de.bsvrz.buv.plugin.dobj.model.DoTyp;
import de.bsvrz.buv.plugin.dobj.util.SelectionProperties;
import de.bsvrz.buv.rw.basislib.einstellungen.EinstellungenWaehler.EinstellungsArt;
import de.bsvrz.buv.rw.basislib.seiteneinstellungen.druck.vorschau.IDruckvorschau;
import de.bsvrz.buv.rw.bitctrl.eclipse.legende.ILegendeBaustein;
import de.bsvrz.buv.rw.bitctrl.eclipse.legende.ITreeLegende;
import de.bsvrz.buv.rw.bitctrl.eclipse.legende.ToggleLegendeAction;

/**
 * Editor zur Anzeige einer Ansicht.
 * 
 * <p>
 * Der Editor wird nicht zum Bearbeiten der Ansicht verwendet. Ein
 * Eclipse-Editor wird verwendet, damit die Ansicht immer im Zentrum des
 * Applikationsfensters dargestellt und ber alle Perspektiven angezeigt wird.
 * 
 * @author BitCtrl Systems GmbH, Falko Schumann
 * @version $Id$
 */
public class AnsichtEditor extends DobjGraphicalEditor<Ansicht> implements
		ITreeLegende, IDruckvorschau {

	/** die Kontext-Hilfe-ID. */
	private static final String HILFE_ID = DObjPlugin.PLUGIN_ID + "."
			+ AnsichtEditor.class.getSimpleName();

	private final class EbeneAdapter extends AdapterImpl {
		@Override
		public void notifyChanged(final Notification notification) {
			final Object notifier = notification.getNotifier();
			final int type = notification.getEventType();

			if (notifier instanceof Ebene) {
				final int featureID = notification.getFeatureID(Ebene.class);
				switch (type) {
				case Notification.SET:
					switch (featureID) {
					case DarstellungPackage.EBENE__VISIBLE:
						toogleLegendeAction.refreshLegende();
						break;
					}
				}
			}
		}
	}

	/** Die ID des Editors. */
	public static final String EDITOR_ID = AnsichtEditor.class.getName();

	/**
	 * Initialisiert den Editor.
	 */
	public AnsichtEditor() {
		super(Ansicht.class);
	}

	private final Adapter ebeneAdapter = new EbeneAdapter();

	private EinstellungsArt einstellungsArt;
	private ToggleLegendeAction toogleLegendeAction;

	@Override
	public void createPartControl(final Composite parent) {
		super.createPartControl(parent);
		geheOnline();
	}

	@Override
	public String getContributorId() {
		return DarstellungActionConstants.ANSICHT_PROPERTIES;
	}

	@Override
	protected EditPartFactory getEditPartFactory() {
		return new DarstellungEditPartFactory();
	}

	@Override
	protected void setInput(final IEditorInput input) {
		super.setInput(input);

		einstellungsArt = (EinstellungsArt) input
				.getAdapter(EinstellungsArt.class);

		final Darstellung darstellung = getModel().getDarstellung();
		for (final Ebene ebene : darstellung.getEbenen()) {
			ebene.eAdapters().add(ebeneAdapter);
		}
	}

	@Override
	protected void configureGraphicalViewer() {
		super.configureGraphicalViewer();

		final ActionRegistry registry = getActionRegistry();

		// Allgemeine Actions

		toogleLegendeAction = new ToggleLegendeAction(this);
		registry.registerAction(toogleLegendeAction);

		// final IAction action0 = new ToggleDarstellungsLegendeAction(this,
		// getModel().getDarstellung());
		// registry.registerAction(action0);

		IAction action = new ToggleEbenenAction(this, getControl());
		registry.registerAction(action);

		action = new ToggleOverviewAction(this, getControl());
		registry.registerAction(action);

		action = new RectangleSelectionAction(this);
		registry.registerAction(action);

		action = new EllipseSelectionAction(this);
		registry.registerAction(action);

		action = new PolygonSelectionAction(this);
		registry.registerAction(action);

		action = new StreckeSelectionAction(this);
		registry.registerAction(action);

		action = new ToggleSynchronizeSelectionAction(this);
		registry.registerAction(action);

		action = new ToggleVerbindungslinieAction(this);
		registry.registerAction(action);

		action = new ToggleBaustelleGueltigAction(this);
		registry.registerAction(action);

		action = new FixViewportAction(this);
		registry.registerAction(action);

		// Actions die SelectionProperties bentigen

		final SelectionProperties selectionProperties = new SelectionProperties();
		selectionProperties.getMatchDoTypen().addAll(
				getModel().getDarstellung().getDoTypen());
		getGraphicalViewer().setProperty(SelectionProperties.class.toString(),
				selectionProperties);

		action = new ToggleTouchedSelectionAction(selectionProperties);
		registry.registerAction(action);

		action = new ToggleSelectionFeedbackAction(selectionProperties);
		registry.registerAction(action);

		action = new ToggleAntiKollisionsAlgorithmusAction(this);
		registry.registerAction(action);

		action = new SelectAusschnittAction(this);
		registry.registerAction(action);

		PlatformUI.getWorkbench().getHelpSystem()
				.setHelp(getControl(), AnsichtEditor.HILFE_ID);
	}

	@Override
	protected IContentOutlinePage getOutlinePage() {
		return new OutlinePage() {

			{
				setMaxBufferSize(100000);
			}

			@Override
			protected EditPartFactory getEditPartFactory() {
				return new DarstellungTreeEditPartFactory();
			}
		};
	}

	@Override
	public void doSave(final IProgressMonitor monitor) {
		final Ansicht ansicht = getModel();

		final IStatus status = EmfUtil.validate(ansicht, DObjPlugin.PLUGIN_ID);
		if (status.getSeverity() != IStatus.OK) {
			ErrorDialog
					.openError(
							getSite().getShell(),
							"Ansicht kann nicht gespeichert werden.",
							"Die zu speichernde Ansicht ist ungltig und kann nicht gespeichert werden.",
							status);
			DObjPlugin.getDefault().getLog().log(status);
			return;
		}

		AnsichtenEinstellungen.INSTANCE.setModellEinstellungen(einstellungsArt,
				ansicht.getName(), ansicht);
		getCommandStack().markSaveLocation();
	}

	@Override
	public Control getControl() {
		return getGraphicalViewer().getControl().getParent();
	}

	@Override
	public List<ILegendeBaustein> getBausteine() {
		final List<ILegendeBaustein> bausteine = new ArrayList<ILegendeBaustein>();

		bausteine.addAll(getBausteine(getGraphicalViewer().getRootEditPart())
				.values());

		return bausteine;
	}

	private Map<DoTyp, ILegendeBaustein> getBausteine(final EditPart editPart) {
		final SortedMap<DoTyp, ILegendeBaustein> bausteine = new TreeMap<DoTyp, ILegendeBaustein>(
				new Comparator<DoTyp>() {

					@Override
					public int compare(final DoTyp dot1, final DoTyp dot2) {
						return dot1.getName().compareTo(dot2.getName());
					}

				});
		ILegendeBaustein baustein = (ILegendeBaustein) editPart
				.getAdapter(ILegendeBaustein.class);
		if (baustein == null) {
			baustein = (ILegendeBaustein) Platform.getAdapterManager()
					.getAdapter(editPart, ILegendeBaustein.class);
		}

		// Nur sichtbare Ebenen bercksichtigen
		if (editPart.getModel() instanceof Ebene) {
			final Ebene ebene = (Ebene) editPart.getModel();
			if (!ebene.isVisible()) {
				return Collections.emptyMap();
			}
		}

		final Object model = editPart.getModel();
		if (model instanceof DoModel) {
			final DoTyp doTyp = ((DoModel) model).getDoTyp();
			if (baustein != null && !bausteine.containsKey(doTyp)) {
				bausteine.put(doTyp, baustein);
			}
		}

		for (final Object e : editPart.getChildren()) {
			bausteine.putAll(getBausteine((EditPart) e));
		}
		return bausteine;
	}

	@Override
	public Object getAdapter(@SuppressWarnings("rawtypes") final Class type) {
		if (type == Darstellung.class) {
			return getModel().getDarstellung();
		}

		return super.getAdapter(type);
	}

	@Override
	public PagePrint getDruckAuftrag() {
		String header = getSite().getPart().getTitle();
		if (header.length() <= 0) {
			header = "Karte";
		}

		final GridPrint grid = new GridPrint();
		grid.addColumn(new GridColumn(GridColumn.DEFAULT_ALIGN,
				GridColumn.DEFAULT_SIZE, GridColumn.DEFAULT_WEIGHT));
		grid.add(new TextPrint(header, new FontData("Arial", 14, SWT.BOLD)));

		// TODO: Image hochskalieren!
		final Display d = getSite().getShell().getDisplay();

		final GraphicalEditPart rootEditPart = (GraphicalEditPart) getGraphicalViewer()
				.getRootEditPart();

		final Rectangle swtR = new Rectangle(rootEditPart.getFigure()
				.getBounds().x, rootEditPart.getFigure().getBounds().y,
				rootEditPart.getFigure().getBounds().width, rootEditPart
						.getFigure().getBounds().height);
		final Image image = new Image(d, swtR);
		final GC gc = new GC(image);
		final SWTGraphics swtg = new SWTGraphics(gc);
		rootEditPart.getFigure().paint(swtg);
		swtg.dispose();
		gc.dispose();
		grid.add(new ImagePrint(image.getImageData()));

		return new PagePrint(new BigPrint(grid));
	}

	@Override
	public String getTitel() {
		return getPartName();
	}

	@Override
	public void dispose() {
		final Darstellung darstellung = getModel().getDarstellung();
		for (final Ebene ebene : darstellung.getEbenen()) {
			ebene.eAdapters().remove(ebeneAdapter);
		}

		super.dispose();
	}

}
