package de.bsvrz.buv.plugin.darstellung.editparts.tree;

import org.eclipse.gef.EditPart;
import org.eclipse.gef.EditPartFactory;

import com.bitctrl.lib.eclipse.emf.gef.editparts.tree.EListNodeTreeEditPart;
import com.bitctrl.lib.eclipse.emf.gef.model.EListNode;

import de.bsvrz.buv.plugin.darstellung.model.Ansicht;
import de.bsvrz.buv.plugin.darstellung.model.Ausschnitt;
import de.bsvrz.buv.plugin.darstellung.model.Darstellung;
import de.bsvrz.buv.plugin.darstellung.model.DarstellungsSpalte;
import de.bsvrz.buv.plugin.darstellung.model.Ebene;
import de.bsvrz.buv.plugin.dobj.internal.DObjPlugin;
import de.bsvrz.buv.plugin.dobj.model.DoModel;
import de.bsvrz.buv.plugin.dobj.model.DoTyp;
import de.bsvrz.dav.daf.main.config.SystemObject;

/**
 * Edit Part Factory fr die Tree Edit Parts einer {@link Ansicht} und
 * {@link Darstellung}.
 * 
 * @author BitCtrl Systems GmbH, Falko Schumann
 * @version $Id$
 */
public class DarstellungTreeEditPartFactory implements EditPartFactory {

	@Override
	public EditPart createEditPart(final EditPart context, final Object model) {
		final EditPart editPart = getEditPart(model);
		editPart.setModel(model);
		return editPart;
	}

	private EditPart getEditPart(final Object model) {
		if (model instanceof Ansicht) {
			return new AnsichtTreeEditPart();
		} else if (model instanceof Ausschnitt) {
			return new AusschnittTreeEditPart();
		} else if (model instanceof Darstellung) {
			return new DarstellungTreeEditPart();
		} else if (model instanceof Ebene) {
			return new EbeneTreeEditPart();
		} else if (model instanceof DarstellungsSpalte) {
			return new DarstellungsSpalteTreeEditPart();
		} else if (model instanceof DoTyp) {
			return new DoTypTreeEditPart();
		} else if (model instanceof EListNode) {
			return new EListNodeTreeEditPart();
		} else if (model instanceof DoModel) {
			return new DoModelTreeEditPart();
		} else if (model instanceof SystemObject) {
			return new SystemObjectTreeEditPart();
		}

		// Kein Fallback, alles andere ist ein Fehler
		String msg = "Kann kein EditPart fr das Modellobjekt erzeugen: ";
		msg += (model != null ? model.getClass() : "null");
		DObjPlugin.getDefault().getLogger().error(msg);
		throw new IllegalArgumentException(msg);
	}

}
