package de.bsvrz.buv.plugin.darstellung.editpolicies;

import java.util.List;

import org.eclipse.core.runtime.Assert;
import org.eclipse.draw2d.IFigure;
import org.eclipse.draw2d.geometry.Point;
import org.eclipse.draw2d.geometry.PrecisionPoint;
import org.eclipse.draw2d.geometry.Translatable;
import org.eclipse.gef.EditPart;
import org.eclipse.gef.GraphicalEditPart;
import org.eclipse.gef.Request;
import org.eclipse.gef.editpolicies.RootComponentEditPolicy;
import org.eclipse.gef.requests.ChangeBoundsRequest;
import org.eclipse.gef.requests.CreateRequest;

import de.bsvrz.buv.plugin.darstellung.model.DarstellungsSpalte;
import de.bsvrz.buv.plugin.darstellung.model.Ebene;
import de.bsvrz.buv.plugin.darstellung.model.StilisierteDarstellung;

public class DarstellungRootComponentEditPolicy extends RootComponentEditPolicy {

	@Override
	public EditPart getTargetEditPart(final Request request) {
		if (request instanceof ChangeBoundsRequest) {
			return getTargetEditPart((ChangeBoundsRequest) request);
		} else if (request instanceof CreateRequest) {
			return getTargetEditPart((CreateRequest) request);
		}

		return super.getTargetEditPart(request);
	}

	private EditPart getTargetEditPart(final ChangeBoundsRequest request) {
		final List<?> editParts = request.getEditParts();
		if (editParts.size() > 0) {
			final EditPart editPart = (EditPart) editParts.get(0);
			final EditPart parent = editPart.getParent();
			if (parent.getModel() instanceof DarstellungsSpalte) {
				final Point location = request.getLocation();
				final Ebene ebene = (Ebene) parent.getParent().getModel();
				final StilisierteDarstellung stilisierteDarstellung = (StilisierteDarstellung) ebene
						.getDarstellung();
				return getDarstellungsSpalte(location, stilisierteDarstellung);
			}
			return parent;
		}

		// fallback
		return null;
	}

	private EditPart getDarstellungsSpalte(final Point location,
			final StilisierteDarstellung stilisierteDarstellung) {
		int offset = 0;
		for (final DarstellungsSpalte spalte : stilisierteDarstellung
				.getSpalten()) {
			offset += spalte.getWidth();
			if (location.x < offset) {
				final EditPart editPart = (EditPart) getHost().getViewer()
						.getEditPartRegistry().get(spalte);
				Assert.isNotNull(editPart,
						"editPart zu Darstellungsspalte nicht gefunden");
				return editPart;
			}
		}

		// fallback: location nicht innerhalb einer Spalte
		return null;
	}

	private EditPart getTargetEditPart(final CreateRequest request) {
		for (final Object child : getHost().getChildren()) {
			final EditPart childEditPart = (EditPart) child;
			final Ebene ebene = (Ebene) childEditPart.getModel();
			if (ebene.isEditable()) {
				if (ebene.getDarstellung() instanceof StilisierteDarstellung) {
					final StilisierteDarstellung stilisierteDarstellung = (StilisierteDarstellung) ebene
							.getDarstellung();
					if (!stilisierteDarstellung.getSpalten().isEmpty()) {
						final Point location = getConstraintFor(request);
						return getDarstellungsSpalte(location,
								stilisierteDarstellung);
					}
				}

				return childEditPart;
			}
		}

		// fallback
		return null;
	}

	private Point getConstraintFor(final CreateRequest request) {
		final Point location = new PrecisionPoint(request.getLocation());
		translateFromAbsoluteToLayoutRelative(location);
		return location;
	}

	private void translateFromAbsoluteToLayoutRelative(final Translatable t) {
		final IFigure figure = getLayoutContainer();
		figure.translateToRelative(t);
		figure.translateFromParent(t);
		final Point negatedLayoutOrigin = getLayoutOrigin().getNegated();
		t.performTranslate(negatedLayoutOrigin.x, negatedLayoutOrigin.y);
	}

	private IFigure getLayoutContainer() {
		return ((GraphicalEditPart) getHost()).getContentPane();
	}

	private Point getLayoutOrigin() {
		return getLayoutContainer().getClientArea().getLocation();
	}

}
