package de.bsvrz.buv.plugin.darstellung.editpolicies;

import org.eclipse.gef.EditPart;
import org.eclipse.gef.Request;
import org.eclipse.gef.RequestConstants;
import org.eclipse.gef.commands.Command;
import org.eclipse.gef.commands.UnexecutableCommand;
import org.eclipse.gef.editpolicies.TreeContainerEditPolicy;
import org.eclipse.gef.requests.ChangeBoundsRequest;
import org.eclipse.gef.requests.CreateRequest;

import de.bsvrz.buv.plugin.darstellung.commands.AddDoModelToEbeneCommand;
import de.bsvrz.buv.plugin.darstellung.commands.ChangeIndexOfDoModelCommand;
import de.bsvrz.buv.plugin.darstellung.model.Ebene;
import de.bsvrz.buv.plugin.dobj.model.DoModel;

/**
 * Tree Container Policy fr eine Ebene.
 * 
 * <p>
 * Untersttzt die folgenden Requests:
 * 
 * <ul>
 * <li>{@link RequestConstants#REQ_MOVE_CHILDREN}</li>
 * <li>{@link RequestConstants#REQ_MOVE}</li>
 * </ul>
 * 
 * @author BitCtrl Systems GmbH, Falko Schumann
 * @version $Id$
 */
public class EbeneTreeEditPolicy extends TreeContainerEditPolicy {

	@Override
	public Command getCommand(final Request req) {
		if (REQ_MOVE.equals(req.getType())) {
			return getMoveCommand((ChangeBoundsRequest) req);
		}

		return super.getCommand(req);
	}

	/**
	 * Erzeugt ein {@link #REQ_MOVE_CHILDREN} und deligiert es an den Parent
	 * Edit Part.
	 * 
	 * @param req
	 *            ein {@link #REQ_MOVE} Request.
	 * @return falls mglich, ein Move-Command.
	 */
	protected Command getMoveCommand(final ChangeBoundsRequest req) {
		final EditPart parent = getHost().getParent();
		if (parent != null) {
			final ChangeBoundsRequest request = new ChangeBoundsRequest(
					REQ_MOVE_CHILDREN);
			request.setEditParts(getHost());
			request.setLocation(req.getLocation());
			request.setMoveDelta(req.getMoveDelta());
			return parent.getCommand(request);
		}

		return UnexecutableCommand.INSTANCE;
	}

	/**
	 * Wird nicht untersttzt.
	 */
	@Override
	protected Command getCreateCommand(final CreateRequest request) {
		return null;
	}

	@Override
	protected Command getAddCommand(final ChangeBoundsRequest request) {
		if (((EditPart) request.getEditParts().get(0)).getModel() instanceof DoModel) {
			final Ebene ebene = (Ebene) getHost().getModel();
			final DoModel model = (DoModel) ((EditPart) request.getEditParts()
					.get(0)).getModel();
			return new AddDoModelToEbeneCommand(model, ebene);
		}

		return null;
	}

	@Override
	protected Command getMoveChildrenCommand(final ChangeBoundsRequest request) {
		final int newIndex = findIndexOfTreeItemAt(request.getLocation());
		final Ebene ebene = (Ebene) getHost().getModel();
		final EditPart child = (EditPart) request.getEditParts().get(0);
		final DoModel model = ((DoModel) child.getModel());
		return new ChangeIndexOfDoModelCommand(model, ebene, newIndex);
	}

}
