package de.bsvrz.buv.plugin.darstellung.wizards;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.util.EcoreUtil;
import org.eclipse.jface.layout.GridDataFactory;
import org.eclipse.jface.viewers.ISelectionChangedListener;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.viewers.ITreeSelection;
import org.eclipse.jface.viewers.SelectionChangedEvent;
import org.eclipse.jface.viewers.TreeViewer;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.ModifyEvent;
import org.eclipse.swt.events.ModifyListener;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Text;

import com.bitctrl.lib.eclipse.emf.viewers.EmfLabelProvider;

import de.bsvrz.buv.plugin.darstellung.model.Ansicht;
import de.bsvrz.buv.plugin.darstellung.model.Darstellung;
import de.bsvrz.buv.plugin.darstellung.model.DarstellungFactory;
import de.bsvrz.buv.plugin.darstellung.util.DarstellungenEinstellungen;
import de.bsvrz.buv.rw.bitctrl.eclipse.viewers.EinstellungenContentProvider;

/**
 * Wizard Page fr die Einstellungen einer Ansicht (Darstellung und Ausschnitt).
 * 
 * @author BitCtrl Systems GmbH, Falko Schumann
 * @version $Id$
 */
public class AnsichtNewWizardPage extends WizardPage implements ModifyListener,
		ISelectionChangedListener {

	private Text name;
	private TreeViewer darstellung;

	/**
	 * Initialisiert die Wizard Page.
	 */
	public AnsichtNewWizardPage(final String pageName) {
		super(pageName);
		setTitle("Neue Ansicht");
		setDescription("Bitte geben Sie den Namen der neuen Ansicht und die zu verwendende Darstellung an.");
		setPageComplete(false);
	}

	@Override
	public void createControl(final Composite parent) {
		final Composite container = new Composite(parent, SWT.NONE);
		container.setLayout(new GridLayout(2, false));

		createName(container);
		createDarstellung(container);

		name.setFocus();
		setControl(container);
	}

	private void createName(final Composite parent) {
		final Label label = new Label(parent, SWT.NONE);
		label.setText("Name");
		name = new Text(parent, SWT.BORDER);
		name.setLayoutData(GridDataFactory.swtDefaults()
				.align(SWT.FILL, SWT.CENTER).grab(true, false).create());
		name.addModifyListener(this);
	}

	private void createDarstellung(final Composite parent) {
		final Label label = new Label(parent, SWT.NONE);
		label.setText("Darstellung");
		label.setLayoutData(GridDataFactory.swtDefaults()
				.align(SWT.LEFT, SWT.TOP).create());
		darstellung = new TreeViewer(parent, SWT.SINGLE | SWT.H_SCROLL
				| SWT.V_SCROLL | SWT.BORDER);
		darstellung.getControl().setLayoutData(
				GridDataFactory.fillDefaults().grab(true, true).create());
		darstellung.setContentProvider(new EinstellungenContentProvider());
		darstellung.setLabelProvider(new EmfLabelProvider());
		darstellung.setInput(DarstellungenEinstellungen.INSTANCE);
		darstellung.addSelectionChangedListener(this);
	}

	private void updatePageComplete() {
		boolean complete = true;

		complete &= !name.getText().isEmpty();
		complete &= !darstellung.getSelection().isEmpty();
		complete &= ((IStructuredSelection) darstellung.getSelection())
				.getFirstElement() instanceof Darstellung;

		setPageComplete(complete);
	}

	/**
	 * Gibt die Ansicht zurck, wie sie auf dieser Wizard Page parametriert
	 * wurde.
	 */
	public Ansicht getAnsicht() {
		final Ansicht ansicht = DarstellungFactory.eINSTANCE.createAnsicht();
		ansicht.setName(name.getText());

		final ITreeSelection selection = (ITreeSelection) darstellung
				.getSelection();
		ansicht.setDarstellung((Darstellung) EcoreUtil
				.copy(((EObject) selection.getFirstElement())));

		return ansicht;
	}

	@Override
	public void dispose() {
		name.removeModifyListener(this);
		darstellung.removeSelectionChangedListener(this);
		super.dispose();
	}

	@Override
	public void modifyText(final ModifyEvent e) {
		updatePageComplete();
	}

	@Override
	public void selectionChanged(final SelectionChangedEvent event) {
		updatePageComplete();
	}

}
