package de.bsvrz.buv.plugin.dobj.actions;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;

import org.eclipse.gef.EditDomain;
import org.eclipse.gef.Tool;
import org.eclipse.gef.ui.actions.WorkbenchPartAction;
import org.eclipse.ui.IWorkbenchPart;

import de.bsvrz.buv.plugin.dobj.editors.DobjEditDomain;

/**
 * Basisklasse fr eine Action die ein {@link Tool} in einer {@link EditDomain}
 * aktiviert.
 * 
 * @author BitCtrl Systems GmbH, Falko Schumann
 * @version $Id$
 */
public class AbstractToolAction extends WorkbenchPartAction implements
		PropertyChangeListener {

	private final Tool tool;

	/**
	 * Initialisiert die Tool Action.
	 * 
	 * @param part
	 *            der Workbench Part, fr den die Action gilt. Dieser muss eine
	 *            {@link DobjEditDomain} als Adapter liefern.
	 * @param text
	 *            der Name der Action.
	 * @param tool
	 *            das zu aktivierende Tool.
	 */
	public AbstractToolAction(final IWorkbenchPart part, final String text,
			final Tool tool) {
		super(part, AS_CHECK_BOX);
		setText(text);
		this.tool = tool;

		setChecked(false);
		getEditDomain().addPropertyChangeListener(this);
	}

	@Override
	protected boolean calculateEnabled() {
		return getEditDomain() != null;
	}

	/**
	 * Gibt das zu aktivierende Tool zurck.
	 */
	public Tool getTool() {
		return tool;
	}

	@Override
	public void dispose() {
		getEditDomain().removePropertyChangeListener(this);
		super.dispose();
	}

	/**
	 * Gibt die {@link EditDomain} des Workbench Parts zurck.
	 */
	protected DobjEditDomain getEditDomain() {
		return (DobjEditDomain) getWorkbenchPart().getAdapter(
				DobjEditDomain.class);
	}

	@Override
	public void run() {
		if (isChecked()) {
			getEditDomain().setActiveTool(tool);
		} else {
			getEditDomain().setActiveTool(getEditDomain().getDefaultTool());
		}
	}

	@Override
	public void propertyChange(final PropertyChangeEvent evt) {
		final String propertyName = evt.getPropertyName();
		final Object newValue = evt.getNewValue();

		if (DobjEditDomain.PROP_ACTIVE_TOOL.equals(propertyName)) {
			setChecked(newValue == tool);
		}
	}

}
