package de.bsvrz.buv.plugin.dobj.actions;

import org.eclipse.gef.SharedImages;
import org.eclipse.jface.action.IAction;
import org.eclipse.ui.IActionBars;
import org.eclipse.ui.actions.RetargetAction;

import de.bsvrz.buv.plugin.dobj.internal.DobjMessages;
import de.bsvrz.buv.plugin.dobj.util.DobjIcons;

/**
 * Factory fr die {@link RetargetAction}s des Plug-ins. Die hier erzeugten
 * Actions tun nichts, sie agieren nur als Platzhalter. Der Workbench Part muss
 * eine Action bereitstellen mit der selben ID, die die tatschliche Aktion
 * ausfhrt. Im Workbench Part muss diese Action mit
 * {@link IActionBars#setGlobalActionHandler(String, IAction)} bekannt gemacht
 * werden.
 * 
 * @author BitCtrl Systems GmbH, Falko Schumann
 * @version $Id$
 */
public abstract class DobjActionFactory {

	/**
	 * Schaltet auf das Tool zum Verschieben des aktuellen Ausschnitt um.
	 */
	public static final DobjActionFactory PAN = new DobjActionFactory(
			"de.bsvrz.buv.plugin.dobj.command.pan") {

		@Override
		public RetargetAction create() {
			final RetargetAction action = new RetargetAction(getCommandId(),
					DobjMessages.Pan_Label, IAction.AS_CHECK_BOX);
			action.setToolTipText(DobjMessages.Pan_Tooltip);
			action.setImageDescriptor(DobjIcons.ActionPan.getImageDescriptor());
			action.setActionDefinitionId(getCommandId());
			return action;
		}
	};

	/**
	 * Schalten auf das Tool zur Selektion mittels eines Polygons um.
	 */
	public static final DobjActionFactory SELECTION_POLYGON = new DobjActionFactory(
			"de.bsvrz.buv.plugin.dobj.command.polygonSelection") {

		@Override
		public RetargetAction create() {
			final RetargetAction action = new RetargetAction(getCommandId(),
					"Polygonselektion", IAction.AS_CHECK_BOX);
			action.setToolTipText("Polygonselektion");
			action.setImageDescriptor(DobjIcons.ActionSelectionPolygon
					.getImageDescriptor());
			action.setActionDefinitionId(getCommandId());
			return action;
		}
	};

	/**
	 * Erzeugt eine Action zum Umschalten auf das Tool zur Selektion mittels
	 * eines Rechtecks.
	 */
	public static final DobjActionFactory SELECTION_RECTANGLE = new DobjActionFactory(
			"de.bsvrz.buv.plugin.dobj.command.rectangleSelection") {

		@Override
		public RetargetAction create() {
			final RetargetAction action = new RetargetAction(getCommandId(),
					DobjMessages.RectangleSelection_Label, IAction.AS_CHECK_BOX);
			action.setToolTipText(DobjMessages.RectangleSelection_Tooltip);
			action.setImageDescriptor(SharedImages.DESC_MARQUEE_TOOL_16);
			action.setActionDefinitionId(getCommandId());
			return action;
		}

	};

	/**
	 * Erzeugt eine Action zum Umschalten auf das Tool zur Selektion mittels
	 * eines Rechtecks.
	 */
	public static final DobjActionFactory SELECTION_ELLIPSE = new DobjActionFactory(
			"de.bsvrz.buv.plugin.dobj.command.ellipseSelection") {

		@Override
		public RetargetAction create() {
			final RetargetAction action = new RetargetAction(getCommandId(),
					DobjMessages.EllipseSelection_Label, IAction.AS_CHECK_BOX);
			action.setToolTipText(DobjMessages.EllipseSelection_Tooltip);
			action.setImageDescriptor(DobjIcons.ActionSelectionEllipse
					.getImageDescriptor());
			action.setActionDefinitionId(getCommandId());
			return action;
		}

	};

	/**
	 * Erzeugt eine Action zum Umschalten auf das Tool zur Selektion einer
	 * Strecke.
	 */
	public static final DobjActionFactory SELECTION_STRECKE = new DobjActionFactory(
			"de.bsvrz.buv.plugin.dobj.command.streckeSelection") {

		@Override
		public RetargetAction create() {
			final RetargetAction action = new RetargetAction(getCommandId(),
					DobjMessages.StreckeSelection_Label, IAction.AS_CHECK_BOX);
			action.setToolTipText(DobjMessages.StreckeSelection_Tooltip);
			action.setImageDescriptor(DobjIcons.ActionSelectionStrecke
					.getImageDescriptor());
			action.setActionDefinitionId(getCommandId());
			return action;
		}

	};

	/**
	 * Aktiviert und Deaktiviert die Teilselektion.
	 */
	public static final DobjActionFactory TOGGLE_TOUCHED_SELECTION = new DobjActionFactory(
			"de.bsvrz.buv.plugin.dobj.command.toogleTouchedSelection") {

		@Override
		public RetargetAction create() {
			final RetargetAction action = new RetargetAction(getCommandId(),
					DobjMessages.ToggleTouchedSelection_Label,
					IAction.AS_CHECK_BOX);
			action.setToolTipText(DobjMessages.ToggleTouchedSelection_Tooltip);
			action.setImageDescriptor(DobjIcons.ActionToggleTouchedSelection
					.getImageDescriptor());
			action.setActionDefinitionId(getCommandId());
			return action;
		}

	};

	/**
	 * Aktiviert und Deaktiviert das Beibehalten des Fensterausschnitts.
	 */
	public static final DobjActionFactory TOGGLE_FIX_VIEWPORT = new DobjActionFactory(
			"de.bsvrz.buv.plugin.dobj.command.toggleFixViewport") {

		@Override
		public RetargetAction create() {
			final RetargetAction action = new RetargetAction(getCommandId(),
					DobjMessages.ToggleFixViewport_Label, IAction.AS_CHECK_BOX);
			action.setToolTipText(DobjMessages.ToggleFixViewport_Tooltip);
			action.setImageDescriptor(DobjIcons.ActionToggleFixViewport
					.getImageDescriptor());
			action.setActionDefinitionId(getCommandId());
			return action;
		}

	};

	/**
	 * Aktiviert und Deaktiviert die Teilselektion.
	 */
	public static final DobjActionFactory TOGGLE_SELECTION_FEEDBACK = new DobjActionFactory(
			"de.bsvrz.buv.plugin.dobj.command.toogleSelectionFeedback") {

		@Override
		public RetargetAction create() {
			final RetargetAction action = new RetargetAction(getCommandId(),
					DobjMessages.ToggleSelectionFeedback_Label,
					IAction.AS_CHECK_BOX);
			action.setToolTipText(DobjMessages.ToggleSelectionFeedback_Tooltip);
			action.setImageDescriptor(DobjIcons.ActionToggleSelectionFeedback
					.getImageDescriptor());
			action.setActionDefinitionId(getCommandId());
			return action;
		}

	};

	/**
	 * Erzeugt eine Action die in einer Ansicht das Umschalten zwischen
	 * Onlinemodus und Offlinemodus erlaubt.
	 */
	public static final DobjActionFactory TOGGLE_ONLINE = new DobjActionFactory(
			"de.bsvrz.buv.plugin.dobj.command.toggleOnline") {

		@Override
		public RetargetAction create() {
			final RetargetAction action = new RetargetAction(getCommandId(),
					DobjMessages.ToggleOnline_Label, IAction.AS_CHECK_BOX);
			action.setToolTipText(DobjMessages.ToggleOnline_Tooltip);
			action.setImageDescriptor(DobjIcons.ActionToggleOnline
					.getImageDescriptor());
			action.setActionDefinitionId(getCommandId());
			return action;
		}

	};

	/**
	 * Erzeugt eine Action zum Umschalten auf das Tool zum Hineinzoomen in einen
	 * Ausschnitt.
	 */
	public static final DobjActionFactory ZOOM_RECTANGLE = new DobjActionFactory(
			"de.bsvrz.buv.plugin.dobj.command.zoomRectangle") {

		@Override
		public RetargetAction create() {
			final RetargetAction action = new RetargetAction(
					"de.bsvrz.buv.plugin.dobj.command.zoomRectangle",
					DobjMessages.RectangleZoom_Label, IAction.AS_CHECK_BOX);
			action.setToolTipText(DobjMessages.RectangleZoom_Tooltip);
			action.setImageDescriptor(DobjIcons.ActionZoomRectangle
					.getImageDescriptor());
			action.setActionDefinitionId("de.bsvrz.buv.plugin.dobj.command.zoomRectangle");
			return action;
		}

	};

	/**
	 * Erzeugt eine Action die in einer Ansicht die Verbindungslinien zwischen
	 * einem verschobenen Objekt und seiner Originalposition ein- und
	 * auschaltet.
	 */
	public static final DobjActionFactory TOGGLE_VERBINDUNGSLINIE = new DobjActionFactory(
			"de.bsvrz.buv.plugin.dobj.command.toggleVerbindungslinie") {

		@Override
		public RetargetAction create() {
			final RetargetAction action = new RetargetAction(getCommandId(),
					DobjMessages.ToggleVerbindungslinie_Label,
					IAction.AS_CHECK_BOX);
			action.setToolTipText(DobjMessages.ToggleVerbindungslinie_Tooltip);
			action.setImageDescriptor(DobjIcons.ActionToggleVerbindingslinie
					.getImageDescriptor());
			action.setActionDefinitionId(getCommandId());
			return action;
		}

	};

	/**
	 * Erzeugt eine Action die in einer Ansicht die Verbindungslinien zwischen
	 * einem verschobenen Objekt und seiner Originalposition ein- und
	 * auschaltet.
	 */
	public static final DobjActionFactory TOGGLE_BAUSTELLE_GUELTIG = new DobjActionFactory(
			"de.bsvrz.buv.plugin.dobj.command.toggleBaustelleGueltig") {

		@Override
		public RetargetAction create() {
			final RetargetAction action = new RetargetAction(getCommandId(),
					DobjMessages.ToggleBaustelleGueltig_Label,
					IAction.AS_CHECK_BOX);
			action.setToolTipText(DobjMessages.ToggleBaustelleGueltig_Tooltip);
			action.setImageDescriptor(DobjIcons.ActionToggleBaustelleGueltig
					.getImageDescriptor());
			action.setActionDefinitionId(getCommandId());
			return action;
		}

	};

	/**
	 * Erzeugt eine Action die den Antikollisionsalgorithmus fr
	 * Darstellunsobjekte ein- und auschaltet.
	 */
	public static final DobjActionFactory TOGGLE_ANTI_KOLLISIONS_ALGORITHMUS = new DobjActionFactory(
			"de.bsvrz.buv.plugin.dobj.command.toggleAntikollisionsAlgorithmus") {

		@Override
		public RetargetAction create() {
			final RetargetAction action = new RetargetAction(getCommandId(),
					DobjMessages.ToggleAntiKollisionsAlgorithmus_Label,
					IAction.AS_CHECK_BOX);
			action.setToolTipText(DobjMessages.ToggleAntiKollisionsAlgorithmus_Tooltip);
			action.setImageDescriptor(DobjIcons.ActionToggleAntikollisionsAlgorithmus
					.getImageDescriptor());
			action.setActionDefinitionId(getCommandId());
			return action;
		}

	};

	private final String commandId;

	private DobjActionFactory(final String commandId) {
		this.commandId = commandId;
	}

	/**
	 * Erzeugt eine neue {@link RetargetAction}.
	 */
	public abstract RetargetAction create();

	/**
	 * Gibt die (Command-)ID der {@link RetargetAction} zurck.
	 */
	public String getCommandId() {
		return commandId;
	}

}
