package de.bsvrz.buv.plugin.dobj.actions;

import org.eclipse.gef.EditPart;
import org.eclipse.gef.RootEditPart;
import org.eclipse.ui.IWorkbenchPart;

import de.bsvrz.buv.plugin.dobj.internal.DobjMessages;
import de.bsvrz.buv.plugin.dobj.requests.OnlineRequest;
import de.bsvrz.buv.plugin.dobj.util.DobjIcons;
import de.bsvrz.buv.plugin.dobj.util.DobjUtil;

/**
 * Action zum Umschalten zwischen Onlinemodus und Offlinemodus.
 * 
 * @author BitCtrl Systems GmbH, Falko Schumann
 * @version $Id$
 */
public class ToggleOnlineAction extends DobjWorkbenchPartAction {

	/**
	 * Initialisiert die Action.
	 * 
	 * @param part
	 *            der Workbench Part fr den die Action gilt.
	 */
	public ToggleOnlineAction(final IWorkbenchPart part) {
		super(part, AS_CHECK_BOX);

		setText(DobjMessages.ToggleOnline_Label);
		setImageDescriptor(DobjIcons.ActionToggleOnline.getImageDescriptor());
		setToolTipText(DobjMessages.ToggleOnline_Tooltip);

		setId(DobjActionFactory.TOGGLE_ONLINE.getCommandId());
		setActionDefinitionId(DobjActionFactory.TOGGLE_ONLINE.getCommandId());
	}

	/**
	 * Sendet an alle Edit Part des Viewer, einschlielich des Root Edit Parts,
	 * ein Request.
	 */
	@Override
	public void run() {
		final OnlineRequest request = new OnlineRequest(isChecked());
		final RootEditPart rootEditPart = getViewer().getRootEditPart();
		rootEditPart.performRequest(request);
		for (final EditPart editPart : DobjUtil.getAllChildren(rootEditPart)) {
			editPart.performRequest(request);
		}
	}

}
