/*
 * Rahmenwerk-Plug-in "Darstellungsobjekte"
 * Copyright (C) 2012 BitCtrl Systems GmbH 
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weissenfelser Strasse 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */
package de.bsvrz.buv.plugin.dobj.decorator.internal.properties.tabbed;

import static org.eclipse.swt.SWT.BORDER;
import static org.eclipse.swt.SWT.CENTER;
import static org.eclipse.swt.SWT.CHECK;
import static org.eclipse.ui.views.properties.tabbed.ITabbedPropertyConstants.HSPACE;

import org.eclipse.jface.viewers.ArrayContentProvider;
import org.eclipse.jface.viewers.ComboViewer;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.ISelectionChangedListener;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.viewers.SelectionChangedEvent;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.FormAttachment;
import org.eclipse.swt.layout.FormData;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.ui.views.properties.tabbed.TabbedPropertySheetPage;
import org.eclipse.ui.views.properties.tabbed.TabbedPropertySheetWidgetFactory;

import com.bitctrl.lib.eclipse.emf.gef.commands.SetCommand;
import com.bitctrl.lib.eclipse.emf.gef.commands.UnsetCommand;

import de.bsvrz.buv.plugin.dobj.decorator.model.DobjDecoratorPackage;
import de.bsvrz.buv.plugin.dobj.decorator.model.LinienStyle;
import de.bsvrz.buv.plugin.dobj.decorator.model.LinienStyleDecorator;
import de.bsvrz.buv.plugin.dobj.model.DoKomponente;
import de.bsvrz.buv.plugin.dobj.properties.AbstractSection;

/**
 * @author BitCtrl Systems GmbH, Christian Hsel
 */
public class LinienStyleDecoratorPropertySection extends
		AbstractSection<LinienStyleDecorator> {

	private Label linienStyleLabel;
	private ComboViewer linienStyleCombo;
	private Button linienStyleUseDefault;

	@Override
	public void createControls(final Composite parent,
			final TabbedPropertySheetPage aTabbedPropertySheetPage) {
		super.createControls(parent, aTabbedPropertySheetPage);

		final TabbedPropertySheetWidgetFactory factory = getWidgetFactory();
		final Composite container = factory.createFlatFormComposite(parent);

		createTransparenz(container);
	}

	private void createTransparenz(final Composite parent) {

		// Widgets anlegen

		final TabbedPropertySheetWidgetFactory factory = getWidgetFactory();
		linienStyleLabel = factory.createLabel(parent, "Linien-Style:", BORDER);
		linienStyleCombo = new ComboViewer(parent, BORDER);
		linienStyleCombo.setContentProvider(new ArrayContentProvider());
		linienStyleCombo.setInput(LinienStyle.values());
		factory.adapt(parent);
		linienStyleUseDefault = factory.createButton(parent,
				"Defaultwert verwenden", CHECK);

		// Widgets layouten

		final FormData comboData = new FormData();
		comboData.left = new FormAttachment(linienStyleLabel, HSPACE);
		comboData.width = 150;
		comboData.top = new FormAttachment(0, 0);
		linienStyleCombo.getControl().setLayoutData(comboData);
		final FormData labelData = new FormData();
		labelData.left = new FormAttachment(0, 0);
		labelData.width = STANDARD_LABEL_WIDTH;
		labelData.top = new FormAttachment(linienStyleCombo.getControl(), 0,
				CENTER);
		linienStyleLabel.setLayoutData(labelData);
		final FormData useDefaultData = new FormData();
		useDefaultData.left = new FormAttachment(linienStyleCombo.getControl(),
				0, HSPACE);
		useDefaultData.top = new FormAttachment(linienStyleCombo.getControl(),
				0, CENTER);
		linienStyleUseDefault.setLayoutData(useDefaultData);

		// Listener anmelden

		linienStyleCombo
				.addSelectionChangedListener(new ISelectionChangedListener() {

					@Override
					public void selectionChanged(
							final SelectionChangedEvent event) {
						final ISelection isel = linienStyleCombo.getSelection();
						if (isel instanceof IStructuredSelection) {
							final Object obj = ((IStructuredSelection) isel)
									.getFirstElement();
							if (obj instanceof LinienStyle) {
								final SetCommand cmd = new SetCommand(
										getElement(),
										DobjDecoratorPackage.Literals.LINIEN_STYLE_DECORATOR__STYLE,
										obj);
								getCommandStack().execute(cmd);
							}
						}
					}
				});

		linienStyleUseDefault.addSelectionListener(new SelectionAdapter() {

			@Override
			public void widgetSelected(final SelectionEvent e) {
				if (linienStyleUseDefault.getSelection()) {
					final UnsetCommand cmd = new UnsetCommand(
							getElement(),
							DobjDecoratorPackage.Literals.LINIEN_STYLE_DECORATOR__STYLE);
					getCommandStack().execute(cmd);
				} else {
					final LinienStyle value = getElement().getStyle();
					final SetCommand cmd = new SetCommand(
							getElement(),
							DobjDecoratorPackage.Literals.LINIEN_STYLE_DECORATOR__STYLE,
							value);
					getCommandStack().execute(cmd);
				}
			}

		});
	}

	@Override
	public void refresh() {
		setLinienStyleToWidget();
		disableLinienStyleIfNecessary();
	}

	private void setLinienStyleToWidget() {
		final LinienStyle style = getElement().getStyle();

		final ISelection isel = linienStyleCombo.getSelection();
		if (isel instanceof IStructuredSelection) {
			final Object obj = ((IStructuredSelection) isel).getFirstElement();
			final boolean isChanged = obj != style;
			if (isChanged) {
				linienStyleCombo.setSelection(new StructuredSelection(style));
			}
		}

	}

	private void disableLinienStyleIfNecessary() {
		final boolean isDoKomponente = getElement().eContainer() instanceof DoKomponente;
		final boolean useDefault = !getElement().isSetStyle();

		linienStyleUseDefault.setSelection(useDefault);

		final boolean enabled = !isDoKomponente && !useDefault;
		linienStyleCombo.getControl().setEnabled(enabled);
		linienStyleLabel.setEnabled(enabled);
		linienStyleUseDefault.setEnabled(!isDoKomponente);
	}

}
