package de.bsvrz.buv.plugin.dobj.figures;

import org.eclipse.draw2d.GridLayout;
import org.eclipse.draw2d.Label;
import org.eclipse.draw2d.Panel;

import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.dav.daf.main.config.AttributeGroup;
import de.bsvrz.dav.daf.main.config.SystemObject;

/**
 * Ein einfacher Tooltip, der fr ein {@link SystemObject} den Namen und die PID
 * anzeigt. Zustzlich wird falls vorhanden die Kurzinfo und Beschreibung aus
 * Konfiguration angezeigt.
 * 
 * @author BitCtrl Systems GmbH, Falko Schumann
 * @version $Id$
 */
public class SystemObjectToolTipFigure extends Panel {

	private Label customNameLabel;
	private final Label nameLabel;
	private Label pidLabel;
	private Label kurzinfoLabel;
	private Label beschreibungLabel;

	/**
	 * Initialisiert den Tooltip. Das Systemobjekt muss spter mit
	 * {@link #setSystemObject(SystemObject)} gesetzt werden.
	 */
	public SystemObjectToolTipFigure() {
		this(null);
	}

	/**
	 * Initialisiert den Tooltip.
	 * 
	 * @param so
	 *            das Systemobjekt fr das der Tooltip bestimmt ist.
	 */
	public SystemObjectToolTipFigure(final SystemObject so) {
		setLayoutManager(new GridLayout());

		nameLabel = new Label();
		add(nameLabel);

		setSystemObject(so);
	}

	/**
	 * bernimmt den Namen und die PID aus dem Systemobjekt und initialisiert
	 * damit den Tooltip.
	 * 
	 * @param systemObject
	 *            das Systemobjekt fr das der Tooltip bestimmt ist.
	 */
	public void setSystemObject(final SystemObject systemObject) {
		if (systemObject == null) {
			nameLabel.setText("Kein Systemobjekt gesetzt.");

			if (pidLabel != null) {
				remove(pidLabel);
				pidLabel = null;
			}

			if (kurzinfoLabel != null) {
				remove(kurzinfoLabel);
				kurzinfoLabel = null;
			}

			if (beschreibungLabel != null) {
				remove(beschreibungLabel);
				beschreibungLabel = null;
			}
		} else {
			nameLabel.setText(systemObject.getName());

			if (pidLabel == null) {
				pidLabel = new Label();
				add(pidLabel);
			}
			pidLabel.setText("(PID: " + systemObject.getPid() + ")");

			final AttributeGroup atg = systemObject.getDataModel()
					.getAttributeGroup("atg.info");
			final Data data = systemObject.getConfigurationData(atg);
			if (data != null) {
				final String kurzinfo = data.getTextValue("kurzinfo").getText();
				if (!kurzinfo.isEmpty()) {
					if (kurzinfoLabel == null) {
						kurzinfoLabel = new Label();
						add(kurzinfoLabel);
					}
					kurzinfoLabel.setText(kurzinfo);
				}

				final String beschreibung = data.getTextValue("beschreibung")
						.getText();
				if (!beschreibung.isEmpty()) {
					if (beschreibungLabel == null) {
						beschreibungLabel = new Label();
						add(beschreibungLabel);
					}
					beschreibungLabel.setText(beschreibung);
				}
			}
		}
	}

	/**
	 * Legt einen benutzerdefinierten Namen fr das Objekt fest. Dieser wird in
	 * der ersten Zeile des Tooltips angezeigt.
	 * 
	 * @param name
	 *            der benutzerdefiniert Name oder <code>null</code>, wenn keiner
	 *            angezeigt werden soll.
	 */
	public void setName(final String name) {
		if (name != null && !name.isEmpty()) {
			if (customNameLabel == null) {
				customNameLabel = new Label();
				add(customNameLabel, 0);
			}

			customNameLabel.setText(name);
		} else if (customNameLabel != null) {
			remove(customNameLabel);
			customNameLabel = null;
		}
	}

}
