package de.bsvrz.buv.plugin.dobj.properties;

import org.eclipse.core.runtime.Assert;
import org.eclipse.emf.common.notify.Adapter;
import org.eclipse.emf.common.notify.Notification;
import org.eclipse.emf.common.notify.impl.AdapterImpl;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.gef.EditPart;
import org.eclipse.gef.commands.CommandStack;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.ui.IWorkbenchPart;
import org.eclipse.ui.part.IContributedContentsView;
import org.eclipse.ui.views.properties.tabbed.AbstractPropertySection;

/**
 * Basisklasse fr Property Sections im Plug-in.
 * 
 * @author BitCtrl Systems GmbH, Falko Schumann
 * @version $Id$
 * @param <T>
 */
public abstract class AbstractSection<T extends EObject> extends
		AbstractPropertySection {

	/** berschreibt die Standardbreite, da hier die Namen lnger sind. */
	protected static final int STANDARD_LABEL_WIDTH = 170;

	private final Adapter adapter = new SectionAdapter();
	private T element;

	@Override
	public void setInput(final IWorkbenchPart part, final ISelection selection) {
		super.setInput(part, selection);

		final Object input = ((IStructuredSelection) selection)
				.getFirstElement();

		Assert.isTrue(input instanceof EditPart);
		final Object model = ((EditPart) input).getModel();
		Assert.isTrue(model instanceof EObject);

		if (element != null) {
			element.eAdapters().remove(adapter);
		}
		element = (T) model;
		element.eAdapters().add(adapter);
	}

	@Override
	public void dispose() {
		if (getElement() != null) {
			getElement().eAdapters().remove(adapter);
		}
	}

	/**
	 * Gibt das zu bearbeitende Objekt zurck.
	 * 
	 * @return das zu bearbeitende Objekt.
	 */
	protected T getElement() {
		return element;
	}

	/**
	 * Gibt den Command Stack zurck.
	 * 
	 * @return der Command Stack, niemals <code>null</code>.
	 */
	protected CommandStack getCommandStack() {
		CommandStack stack = (CommandStack) getPart().getAdapter(
				CommandStack.class);
		if (stack == null) {
			final IContributedContentsView contributedView = (IContributedContentsView) getPart()
					.getAdapter(IContributedContentsView.class);
			stack = (CommandStack) contributedView.getContributingPart()
					.getAdapter(CommandStack.class);
		}

		Assert.isNotNull(stack, "Der Command Stack ist nicht verfgbar.");
		return stack;
	}

	private class SectionAdapter extends AdapterImpl {

		@Override
		public void notifyChanged(final Notification notification) {
			final int type = notification.getEventType();

			switch (type) {
			case Notification.SET:
			case Notification.UNSET:
			case Notification.ADD:
			case Notification.ADD_MANY:
			case Notification.MOVE:
			case Notification.REMOVE:
			case Notification.REMOVE_MANY:
				refresh();
				break;
			}
		}

	}

}
