package de.bsvrz.buv.plugin.dobj.properties;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.FormAttachment;
import org.eclipse.swt.layout.FormData;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Spinner;
import org.eclipse.ui.views.properties.tabbed.ITabbedPropertyConstants;
import org.eclipse.ui.views.properties.tabbed.TabbedPropertySheetPage;
import org.eclipse.ui.views.properties.tabbed.TabbedPropertySheetWidgetFactory;

import com.bitctrl.lib.eclipse.emf.gef.commands.SetCommand;
import com.bitctrl.lib.eclipse.emf.gef.model.GefPackage;
import com.bitctrl.lib.eclipse.emf.gef.model.Rotated;

import de.bsvrz.buv.plugin.dobj.model.DoKomponente;
import de.bsvrz.buv.plugin.dobj.model.DoModel;

/**
 * Tabbed Property Section f�r ein Darstellungsobjekt {@link DoModel}.
 * 
 * <p>
 * Bearbeitbar sind die folgenden Eingenschaften:
 * <ul>
 * <li>Drehung</li>
 * </ul>
 * TODO: Fixpunkt konfigurierbar machen (anchor)!
 * 
 * @author BitCtrl Systems GmbH, Thierfelder
 * @version $Id$
 */
public class RotatedSection extends AbstractSection<Rotated> {

	// drehung
	private Label drehungLabel;
	private Spinner drehungSpinner;

	@Override
	public void createControls(final Composite parent,
			final TabbedPropertySheetPage aTabbedPropertySheetPage) {
		super.createControls(parent, aTabbedPropertySheetPage);

		final TabbedPropertySheetWidgetFactory factory = getWidgetFactory();
		final Composite container = factory.createFlatFormComposite(parent);

		createDrehung(container);
	}

	private void createDrehung(final Composite parent) {
		final TabbedPropertySheetWidgetFactory factory = getWidgetFactory();
		FormData data;

		drehungSpinner = new Spinner(parent, SWT.BORDER);
		drehungSpinner.setMinimum(-360);
		drehungSpinner.setMaximum(360);
		drehungSpinner.setIncrement(1);
		factory.adapt(parent);
		data = new FormData();
		data.left = new FormAttachment(0, STANDARD_LABEL_WIDTH);
		data.right = new FormAttachment(100, 0);
		data.top = new FormAttachment(0, ITabbedPropertyConstants.VSPACE);
		drehungSpinner.setLayoutData(data);

		drehungLabel = factory.createLabel(parent, "Drehung:");
		data = new FormData();
		data.left = new FormAttachment(0, 0);
		data.right = new FormAttachment(drehungSpinner,
				-ITabbedPropertyConstants.HSPACE);
		data.top = new FormAttachment(drehungSpinner, 0, SWT.CENTER);
		drehungLabel.setLayoutData(data);

		drehungSpinner.addSelectionListener(new SelectionAdapter() {

			@Override
			public void widgetSelected(final SelectionEvent e) {
				final double value = drehungSpinner.getSelection();
				final SetCommand cmd = new SetCommand(getElement(),
						GefPackage.Literals.ROTATED__ANGLE, value);
				getCommandStack().execute(cmd);
			}

		});
	}

	@Override
	public void refresh() {
		if (drehungSpinner.getSelection() != getElement().getAngle().intValue()) {
			drehungSpinner.setSelection(getElement().getAngle().intValue());
		}

		final boolean isInKompositum = getElement().eContainer() instanceof DoKomponente;
		drehungLabel.setEnabled(!isInKompositum);
		drehungSpinner.setEnabled(!isInKompositum);

	}

}
