package de.bsvrz.buv.plugin.dobj.requests;

import org.eclipse.gef.Request;

/**
 * Request zur Aufforderung die Verbindungslinie eines verschobenen Objekts zu
 * seiner Originalposition ein- oder auszuschalten.
 * 
 * @author BitCtrl Systems GmbH, Falko Schumann
 * @version $Id: VerbindungslinieRequest.java 25950 2010-08-31 10:38:16Z Schumann $
 */
public class VerbindungslinieRequest extends Request {

	private final boolean verbindungsLinie;

	/**
	 * Initialisiert den Request.
	 * 
	 * @param verbindungsLinie
	 *            das Flag ob die Verbindungslinie ein- oder ausgeschalten
	 *            werden soll.
	 */
	public VerbindungslinieRequest(final boolean verbindungsLinie) {
		super(DobjRequestConstants.REQ_VERBINDUNGSLINIE);
		this.verbindungsLinie = verbindungsLinie;
	}

	/**
	 * Gibt das Flag ob die Verbindungslinie ein- oder ausgeschalten werden soll
	 * zurck.
	 * 
	 * @return <code>true</code>, wenn die Verbindungslinie angezeigt werden
	 *         soll und <code>false</code>, wenn sie nicht angezeigt werden
	 *         soll.
	 */
	public boolean isVerbindungsLinie() {
		return verbindungsLinie;
	}

}
