package de.bsvrz.buv.plugin.dobj.tools;

import java.awt.geom.Ellipse2D;
import java.util.Collection;
import java.util.Iterator;

import org.eclipse.draw2d.IFigure;
import org.eclipse.draw2d.geometry.Rectangle;
import org.eclipse.gef.EditPart;
import org.eclipse.gef.GraphicalEditPart;

import de.bsvrz.buv.plugin.dobj.figures.EllipseFeedbackFigure;

public class EllipseSelectionTool extends RectangleSelectionTool {

	@Override
	protected String getCommandName() {
		return "Rechteckselektion";
	}

	@Override
	protected void calculateNewSelection(final Collection newSelections,
			final Collection deselections) {
		final Rectangle marqueeRect = getMarqueeSelectionRectangle();
		for (final Iterator itr = getAllChildren().iterator(); itr.hasNext();) {
			final GraphicalEditPart child = (GraphicalEditPart) itr.next();
			if (!isValidModel(child.getModel())) {
				continue;
			}

			final IFigure figure = child.getFigure();
			if (!child.isSelectable()
					|| child.getTargetEditPart(MARQUEE_REQUEST) != child
					|| !isFigureVisible(figure) || !figure.isShowing()) {
				continue;
			}

			final Rectangle r = figure.getBounds().getCopy();
			figure.translateToAbsolute(r);

			final Ellipse2D marqueeEllipse = new Ellipse2D.Double();
			marqueeEllipse.setFrame(marqueeRect.x, marqueeRect.y,
					marqueeRect.width, marqueeRect.height);

			if (isTouchedSelection()) {
				if (marqueeEllipse.contains(r.x, r.y, r.width, r.height)
						|| marqueeEllipse.intersects(r.x, r.y, r.width,
								r.height)) {
					if (child.getSelected() == EditPart.SELECTED_NONE
							|| getSelectionMode() != TOGGLE_MODE) {
						newSelections.add(child);
					} else {
						deselections.add(child);
					}
				}
			} else {
				if (marqueeEllipse.contains(r.x, r.y, r.width, r.height)) {
					if (child.getSelected() == EditPart.SELECTED_NONE
							|| getSelectionMode() != TOGGLE_MODE) {
						newSelections.add(child);
					} else {
						deselections.add(child);
					}
				}
			}
		}
	}

	@Override
	protected IFigure createMarqueeFeedbackFigure() {
		return new EllipseFeedbackFigure();
	}

}
